@@ -45,6 +45,14 @@ class Webserver:
         response = await self.router_handler.resolve(method, self.path, request, self.headers)
 
         headers = []
+        if method == "OPTIONS":
+            self.send_header("Access-Control-Allow-Origin", "*", headers)
+            self.send_header("Access-Control-Allow-Headers", "Origin, X-Requested-With, Content-Type, Accept, Authorization", headers)
+            self.send_header("Access-Control-Allow-Credentials", "True", headers)
+
+            headers = await self.get_headers(headers, self.response_protocol, HTTP_OK)
+            return headers
+
         self.send_header("Content-Type", response["content_type"], headers)
         self.send_header("Content-Length", str(len(response["content"])), headers)
         self.send_header("Connection", "Keep-Alive", headers)
@@ -89,7 +97,7 @@ class Webserver:
         found_length = False
         content_length = 999999999999
         while True:
-            fragment = (await loop.sock_recv(client, 1024)).decode('utf8')
+            fragment = (await loop.sock_recv(client, 4096)).decode('utf8')
             fragments.append(fragment)
             if not found_length:
                 i = "".join(fragments).find('Content-Length:')
@@ -100,7 +108,7 @@ class Webserver:
                         content_length = int(value[1].strip())
                         found_length = True
 
-            if not found_length and fragment.find('GET') != -1 and len(fragment) < 1024:
+            if not found_length and (fragment.find('GET') != -1 or fragment.find('OPTIONS') != -1) and len(fragment) < 4096:
                 content_length = len("".join(fragments))
 
             if len("".join(fragments)) >= content_length or len("".join(fragments)) == 0:
@@ -127,7 +135,7 @@ class Webserver:
 
         self.headers = initial.split("\n")
 
-        method_list = [TINA4_GET, TINA4_ANY, TINA4_POST, TINA4_PATCH]
+        method_list = [TINA4_GET, TINA4_ANY, TINA4_POST, TINA4_PATCH, TINA4_OPTIONS]
 
         contains_method = [ele for ele in method_list if (ele in self.method)]
 
