@@ -80,7 +80,7 @@ if __name__ == '__main__' or __name__ == 'tina4_python':
     # Start up a webserver based on params passed on the command line
     HOSTNAME = "localhost"
     PORT = 7145
-    if len(sys.argv) > 1 and sys.argv[1]:
+    if len(sys.argv) > 1 and sys.argv[1].isdigit():
         PORT = sys.argv[1]
         if ":" in PORT:
             SERVER_CONFIG = PORT.split(":")
